@@ -43,4 +43,7 @@ NanosToPOSIXct <- function(nanos) {
   )
   
 }
-  
\ No newline at end of file
+
+assert <- function (expr, error) {
+  if (! expr) stop(error, call. = FALSE)
+}
\ No newline at end of file
